#ifndef DISCRETECM_H_
#define DISCRETECM_H_
#include "cdf.h"
#endif
